@@ -21,6 +21,3 @@ from .Plugin import Plugin
 
 class Dlc(Plugin):
     """Represents a single DLC."""
-
-    def __init__(self, filename):
-        super(Dlc, self).__init__(filename)
