@@ -16,26 +16,27 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from abc import ABCMeta
 import re
+from .exceptions import NameNotFoundError
 
 
 class Plugin(object):
     """Represents a single plugin (DLC/mod)."""
 
-    def __init__(self, filename):
+    __metaclass__ = ABCMeta
+
+    def __init__(self, filename, name, enabled=True):
         self.filename = filename
-        self.name = self.get_name()
-        self.enabled = True
-
-    def get_name(self):
-        """Extract the name of the plugin from the file."""
-        with open(self.filename) as plugin_file:
-            plugin_contents = plugin_file.read()
+        self.name = name
+        self.enabled = enabled
 
+    @staticmethod
+    def get_plugin_name(fileobj):
         try:
-            return re.search('^name[ \t]*=[ \t]*"(.*)"', plugin_contents,
+            return re.search('^name[ \t]*=[ \t]*"(.*)"', fileobj.read(),
                              re.MULTILINE).group(1)
         except AttributeError:
-            # TODO: Log instance of plugin name not found. Find a way to present
-            #       it to user.
-            return self.filename
+            # TODO: Log instance of plugin name not found. Find a way to
+            #       present it to user.
+            raise NameNotFoundError()
