@@ -17,6 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
+from subprocess import Popen
 
 
 def make_command(game_path, binary, excluded_dlcs, mods):
@@ -29,3 +30,6 @@ def make_command(game_path, binary, excluded_dlcs, mods):
 
     return command
 
+
+def execute_command(command):
+    return Popen(command)
