@@ -18,13 +18,20 @@
 
 """All exceptions used in the PyParadox code base are defined here."""
 
+
 class PyParadoxException(Exception):
     """Base exception class. All PyParadox-specific exceptions should inherit
     from this class.
     """
 
+
 class PySideImportError(PyParadoxException):
     """Could not import PySide/Qt."""
 
-class RunGameError(PyParadoxException):
-    """Could not launch the game."""
+
+class GameNotExistError(PyParadoxException):
+    """String identifier for game is not valid."""
+
+
+class NameNotFoundError(PyParadoxException):
+    """Name not found in plugin file."""
