@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 # PyParadox is a *nix launcher for Paradox games.
@@ -18,22 +18,40 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
-import pyparadox
-from pyparadox.exceptions import PySideImportError
-from pyparadox.gui.MainWindow import MainWindow
+from . import __version__
+from .exceptions import PySideImportError
+from .Config import Config
+from .gui.MainWindow import MainWindow
 try:
-    from PySide import QtCore, QtGui
-    from PySide.QtCore import Signal, Slot
+    from PySide import QtGui
 except ImportError:
     raise PySideImportError
 
 
+def pyparadox_eu4():
+    main("eu4")
+
+
+def pyparadox_ck2():
+    main("ck2")
+
+
 def main(game):
     app = QtGui.QApplication(sys.argv)
-    app.setApplicationVersion(pyparadox.__version__)
+    app.setApplicationVersion(__version__)
     app.setApplicationName(app.tr("PyParadox"))
+    app.setOrganizationName(app.tr("PyParadox"))
+    app.process = None
 
-    form = MainWindow(game)
+    config = Config(game, app.applicationName(), app.organizationName())
+
+    form = MainWindow(game, config)
     form.show()
 
     app.exec_()
+
+    if app.process is not None:
+        process = app.process
+        app.exit()
+        process.wait()
+    sys.exit()
